package com.vetti.hotake.service;

import java.util.List;
import com.vetti.hotake.domain.HotakeInitScreQuestionsReplyRecordInfo;
import com.vetti.hotake.domain.vo.HotakeInitScreQuestionsReplyRecordInfoVo;

/**
 * 初步筛选问题回答记录信息Service接口
 * 
 * @author wangxiangshun
 * @date 2025-12-14
 */
public interface IHotakeInitScreQuestionsReplyRecordInfoService 
{
    /**
     * 查询初步筛选问题回答记录信息
     * 
     * @param id 初步筛选问题回答记录信息主键
     * @return 初步筛选问题回答记录信息
     */
    public HotakeInitScreQuestionsReplyRecordInfo selectHotakeInitScreQuestionsReplyRecordInfoById(Long id);

    /**
     * 查询初步筛选问题回答记录信息列表
     * 
     * @param hotakeInitScreQuestionsReplyRecordInfo 初步筛选问题回答记录信息
     * @return 初步筛选问题回答记录信息集合
     */
    public List<HotakeInitScreQuestionsReplyRecordInfo> selectHotakeInitScreQuestionsReplyRecordInfoList(HotakeInitScreQuestionsReplyRecordInfo hotakeInitScreQuestionsReplyRecordInfo);

    /**
     * 新增初步筛选问题回答记录信息
     * 
     * @param hotakeInitScreQuestionsReplyRecordInfo 初步筛选问题回答记录信息
     * @return 结果
     */
    public int insertHotakeInitScreQuestionsReplyRecordInfo(HotakeInitScreQuestionsReplyRecordInfo hotakeInitScreQuestionsReplyRecordInfo);

    /**
     * 修改初步筛选问题回答记录信息
     * 
     * @param hotakeInitScreQuestionsReplyRecordInfo 初步筛选问题回答记录信息
     * @return 结果
     */
    public int updateHotakeInitScreQuestionsReplyRecordInfo(HotakeInitScreQuestionsReplyRecordInfo hotakeInitScreQuestionsReplyRecordInfo);

    /**
     * 批量删除初步筛选问题回答记录信息
     * 
     * @param ids 需要删除的初步筛选问题回答记录信息主键集合
     * @return 结果
     */
    public int deleteHotakeInitScreQuestionsReplyRecordInfoByIds(Long[] ids);

    /**
     * 删除初步筛选问题回答记录信息信息
     * 
     * @param id 初步筛选问题回答记录信息主键
     * @return 结果
     */
    public int deleteHotakeInitScreQuestionsReplyRecordInfoById(Long id);

    /**
     * 批量新增初步筛选问题回答记录信息
     *
     * @param hotakeInitScreQuestionsReplyRecordInfoList 初步筛选问题回答记录信息列表
     * @return 结果
     */
    public int batchInsertHotakeInitScreQuestionsReplyRecordInfo(List<HotakeInitScreQuestionsReplyRecordInfo> hotakeInitScreQuestionsReplyRecordInfoList);


    /**
     * 初步筛选问题回答记录信息批量保存
     *
     * @param initScreQuestionsReplyRecordInfoVo 初步筛选问题回答记录信息数据
     * @return 结果
     */
    public int saveHotakeInitScreQuestionsReplyRecordInfo(HotakeInitScreQuestionsReplyRecordInfoVo initScreQuestionsReplyRecordInfoVo);

}
